@@ -1,5 +1,5 @@
 from colorama import Fore, Back, Style
-from workspace import commands
+from workspace import commands, message
 
 name = "help"
 help = """Provides help about commands"""
@@ -11,7 +11,7 @@ def run(args):
   print('')
 
   for entry in commands.commands:
-    print(Style.BRIGHT + Fore.BLUE + "wks" + Fore.RESET + " " + entry.name + ' ' + Style.RESET_ALL + entry.usage)
+    message.bright(message.emphasis("wks") + " " + entry.name + ' ' + Style.RESET_ALL + entry.usage)
     lines = entry.help.strip().split("\n")
     lines = ["    " + line for line in lines]
     print("\n".join(lines))
